# SPDX-FileCopyrightText: Copyright (c) 2020 Dan Halbert for Adafruit Industries
#
# SPDX-License-Identifier: MIT
"""
`adafruit_airlift`
================================================================================

Manage AirLift coprocessors for use with Wifi and Bluetooth


* Author(s): Dan Halbert

Implementation Notes
--------------------

**Software and Dependencies:**

* Adafruit CircuitPython firmware for the supported boards:
  https://github.com/adafruit/circuitpython/releases
"""

# imports

__version__ = "1.0.18"
__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_AirLift.git"
